#
# spec file for package ethtool
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ethtool
Version:        6.11
Release:        1.3
Summary:        Utility for examining and tuning Ethernet-based network interfaces
License:        GPL-2.0-only
Group:          Productivity/Networking/Diagnostic
URL:            https://www.kernel.org/pub/software/network/ethtool/

#Git-Clone:	git://git.kernel.org/pub/scm/network/ethtool/ethtool
Source:         https://www.kernel.org/pub/software/network/ethtool/%{name}-%{version}.tar.xz
Source2:        https://www.kernel.org/pub/software/network/ethtool/%{name}-%{version}.tar.sign
Source3:        %{name}.keyring
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(libmnl)

%description
Ethtool is a small utility for examining and tuning ethernet-based
network interfaces.  See the man page for more details.

%package bash-completion
Summary:        Bash completion for ethtool
Group:          System/Shells
Requires:       %{name}
Requires:       bash-completion
%if 0%{?suse_version} >= 1500
Supplements:    (%{name} and bash-completion)
%else
Supplements:    packageand(%{name}:bash-completion)
%endif
BuildArch:      noarch

%description bash-completion
bash command line completion support for ethtool.

%prep
%setup -q

%build
export CFLAGS="%optflags -Wall -Wextra -Wstrict-prototypes -Wformat-security -Wpointer-arith"
%configure
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"

%files
%defattr(-,root,root)
%{_sbindir}/ethtool
%{_mandir}/man8/ethtool.8*
%if (0%{?suse_version} >= 1500) || (0%{?sle_version} >= 120300)
%license COPYING
%else
%doc COPYING
%endif
%doc AUTHORS NEWS

%files bash-completion
%defattr(-,root,root)
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/ethtool

%changelog
* Tue Oct  8 2024 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 6.11
  * Feature: cmis: print active and inactive firmware versions
  * Feature: flash transceiver module firmware (--flash-module-firmware)
  * Feature: add T1BRR 10Mb/s mode to link mode tables
  * Feature: support for disabling netlink from command line
  * Fix: fix lanes parameter format specifier
  * Fix: add missing clause 33 PSE manual description
  * Fix: qsf: Better handling of Page A2h netlink read failure
  * Fix: rss: retrieve ring count using ETHTOOL_GRXRINGS ioctl (-x)
* Fri Aug  9 2024 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 6.10
  * Feature: suport for PoE in PSE (--show-pse and --set-pse)
  * Feature: add statistics support to tsinfo (-T)
  * Feature: add JSON output to base command (no option)
  * Feature: add JSON output to EEE info (--show-eee)
  * Fix: qsfp: better handling on page 03h read failure (-m)
  * Fix: handle zero arguments for module eeprom dump (-m)
  * Fix: check for missing arguments in do_srxfh() (-X)
  * Misc: more descriptive error when JSON output is not available
* Thu May 23 2024 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 6.9
  * Feature: support for rx-flow-hash gtp (-N)
  * Feature: support for RSS input transformation (-X)
  * Fix: typo in coalescing output (-c)
  * Fix: document all debugging flags in man page
* Sun Jan 28 2024 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 6.7
  * Feature: support for setting TCP data split
  * Fix: fix new gcc14 warning
  * Fix: fix SFF-8472 transceiver module identification (-m)
* Thu Nov 23 2023 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 6.6
  * Feature: support for more CMIS transceiver modules (-m)
  * Fix: fix build on systems with old kernel uapi headers
* Tue Sep 12 2023 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 6.5
  * Feature: register dump for hns3 driver (-d)
  * Fix: fix fallback to ioctl for sset (-s)
  * Fix: fix empty slot search in rmgr (-N)
* Sat Jul  1 2023 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 6.4
  * Feature: get/set Tx push buffer length (-G)
  * Feature: sff-8636 and cmis: report LOL / LOS / Tx Fault (-m)
  * Fix: fix duplex setting parser (-s)
  * Misc: check and require C11 language standard
  * Misc: clean up obsolete pre-build checks
* Sat Jul  1 2023 Michal Kubecek <mkubecek@suse.cz>
- make ethtool-bash-completion noarch
* Mon May  8 2023 Michal Kubeček <mkubecek@suse.cz>
- update to upstream release 6.3
  * Feature: PLCA support (--[gs]et-plca-cfg, --get-plca-status)
  * Feature: MAC Merge layer support (--show-mm, --set-mm)
  * Feature: pass source of statistics for port stats
  * Feature: get/set rx push in ringparams (-g and -G)
  * Feature: coalesce tx aggregation parameters (-c and -C)
  * Feature: PSE and PD devices (--show-pse, --set-pse)
  * Fix: minor fixes of help text (--help)
  * Fix: fix build on systems with older system headers
  * Fix: fix netlink support when PLCA is not present (no option)
  * Fix: fixes for issues found with gcc13 -fanalyzer
  * Fix: fix return code in rxclass_rule_ins (-N)
  * Fix: more robust argc/argv handling
* Fri Mar  3 2023 Callum Farmer <gmbr3@opensuse.org>
- Split bash-completion to separate sub-package
* Tue Feb 21 2023 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 6.2
  * Feature: link down event statistics (no option)
  * Feature: JSON output for coalesce (-c)
  * Feature: new link modes (no option)
  * Feature: JSON output for ring (-g)
  * Feature: netlink handler for RSS get (-x)
  * Fix: fix boolean value output in JSON output
- enforce "-std=c11" on SLE <= 12 where the default is older
* Mon Dec 19 2022 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 6.1
  * Feature: update link mode tables
  * Feature: register dump for NXP ENETC driver (-d)
  * Feature: report TCP header-data split (-g)
  * Feature: support new message types in pretty print
  * Fix: man page syntax fixes
* Mon Oct 10 2022 Michal Kubeček <mkubecek@suse.cz>
- update to upstream release 6.0
  * Fix: advertisement modes autoselection by lanes (-s)
* Sun Aug 21 2022 Michal Kubeček <mkubecek@suse.cz>
- update to upstream release 5.19
  * Feature: get/set tx push (-g and -G)
  * Feature: register dump support for TI CPSW
  * Feature: register dump support for lan743x chipset
  * Fix: fix missing sff-8472 output in netlink path
  * Fix: fix EEPROM byte write
* Mon Jun 13 2022 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 5.18
  * Feature: get/set cqe size (-g and -G)
  * Fix: fix typo in man page
  * Fix: fix help text alignment
  * Fix: improve attribute label (--show-fec)
* Mon Apr  4 2022 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 5.17
  * Feature: transceiver module power mode (--set-module)
  * Feature: transceiver module extended state (--show-module)
  * Feature: get/set rx buffer length (-g and -G)
  * Feature: tx copybreak buffer size (--get-tunable and
  - -set-tunable)
  * Feature: JSON output for features (-k)
  * Feature: support OSFP transceiver modules (-m)
  * Fix: add missing free() calls (--get-tunable and --set-tunable)
* Tue Jan 18 2022 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 5.16
  * Feature: use memory maps for module EEPROM parsing (-m)
  * Feature: show CMIS diagnostic information (-m)
  * Fix: fix dumping advertised FEC modes (--show-fec)
  * Fix: ignore cable test notifications from other devices
    (--cable-test)
  * Fix: do not show duplicate options in help text (--help)
* Tue Nov  9 2021 Michal Kubecek <mkubecek@suse.cz>
- update to upstream release 5.15
  * Feature: new extended link substates for bad signal (no arg)
  * Feature: coalesce cqe mode attributes (-c and -C)
  * Fix: multiple fixes of EEPROM module data parsing (-m)
  * Fix: fix condition to display MDI-X info (no arg)
* Sun Sep 12 2021 Michal Kubecek <mkubecek@suse.cz>
- update to new upstream release 5.14
  * Feature: do not silently ignore --json if unsupported
  * Feature: support new message types in pretty print
* Thu Jul  8 2021 Michal Kubecek <mkubecek@suse.cz>
- update to new upstream release 5.13
  * Feature: netlink handler for FEC (--show-fec and --set-fec)
  * Feature: FEC stats support (--show-fec)
  * Feature: standard based stats support (-S)
  * Feature: netlink handler for module EEPROM dump (-m)
  * Feature: page, bank and i2c selection in module dump (-m)
* Sun May  2 2021 Michal Kubecek <mkubecek@suse.cz>
- update to new upstream release 5.12
  * Feature: support lanes count (no option and -s)
  * Fix: fix help message for master-slave parameter (-s)
  * Fix: better error message for master-slave in ioctl code path
  * Fix: get rid of compiler warnings in "make check"
* Wed Dec 16 2020 Michal Kubecek <mkubecek@suse.cz>
- update to new upstream release 5.10
  * infrastructure for JSON output
  * separate FLAGS in -h output
  * use policy dumps to check flags support
  * show pause stats (-a)
  * pretty printing of policy dumps
  * improve error message when SFP module is missing
  * fix use after free in netlink_run_handler()
  * fix leaked instances of struct nl_socket
  * improve compatibility between netlink and ioctl (-s)
- drop patches present in 5.10 release:
  * ethtool-Improve-compatibility-between-netlink-and-io.patch
  * netlink-do-not-send-messages-and-process-replies-in-.patch
  * netlink-fix-leaked-instances-of-struct-nl_socket.patch
  * netlink-fix-use-after-free-in-netlink_run_handler.patch
* Wed Nov 11 2020 Michal Kubecek <mkubecek@suse.cz>
- backport post-5.9 fixes
  * netlink-fix-use-after-free-in-netlink_run_handler.patch
  * netlink-fix-leaked-instances-of-struct-nl_socket.patch
  * netlink-do-not-send-messages-and-process-replies-in-.patch
  * ethtool-Improve-compatibility-between-netlink-and-io.patch
* Thu Oct 15 2020 Michal Kubecek <mkubecek@suse.cz>
- update to new upstream release 5.9
  * extended link state
  * QSFP-DD support
  * tunnel information (--show-tunnels)
  * Broadcom bnxt support
  * improve compatibility between ioctl and netlink output
  * fix cable test TDR amplitude output
  * get rid of build warnings
  * fix null pointer dereference running against old kernel (no arg)
  * update link mode tables
  * fix memory leaks and error handling found by static analysis
- update compiler flags
  * -Wno-missing-field-initializers no longer needed
  * replace -W with -Wextra (preferred form)
* Tue Aug  4 2020 Michal Kubecek <mkubecek@suse.cz>
- update to new upstream release 5.8
  * netlink handler for device features
  * netlink handler for private flags
  * netlink handler for ring sizes
  * netlink handler for channels counts
  * netlink handler for coalescing parameters
  * netlink handler for pause parameters
  * netlink handler for EEE settings
  * netlink handler for timestamping info
  * master/slave configuration support
  * LINKSTATE SQI support
  * cable test support
  * cable test TDR support
  * JSON output for cable test commands
  * igc driver support
  * support for get/set ethtool_tunable
  * dsa: mv88e6xxx: add pretty dump for 88E6352 SERDES
  * fix some build warnings
- drop patches present in 5.8 release:
  * netlink-fix-build-warnings.patch
  * netlink-fix-error-message-suppression.patch
  * netlink-fix-unwanted-switch-fall-through-in-family_i.patch
* Tue Aug  4 2020 Michal Kubecek <mkubecek@suse.cz>
- ethtool.keyring:
  add new upstream maintainer's key (F4554567B91DE934)
* Fri Jun 12 2020 Michal Kubecek <mkubecek@suse.cz>
- prevent misleading netlink error message when running on kernel
  without ethtool netlink support:
  netlink-fix-error-message-suppression.patch
* Sun Jun  7 2020 Michal Kubecek <mkubecek@suse.cz>
- update to new upstream release 5.7
  * support LLRS (Low Latency Reed Solomon) FEC mode
  * accept long legacy flag names (-K)
  * support for newer SFF-8024 compliance codes
  * report transceiver when reported by kernel
  * improve fallback from netlink to ioctl and error messages
- drop patches present in 5.7 release:
  netlink-show-netlink-error-even-without-extack.patch
  features-accept-long-legacy-flag-names-when-setting-.patch
  refactor-interface-between-ioctl-and-netlink-code.patch
  netlink-use-genetlink-ops-information-to-decide-abou.patch
- refresh
  netlink-fix-build-warnings.patch
- fix cherry picked from upstream git:
  netlink-fix-unwanted-switch-fall-through-in-family_i.patch
* Fri May 15 2020 Michal Kubecek <mkubecek@suse.cz>
- update upstream references:
  features-accept-long-legacy-flag-names-when-setting-.patch
  netlink-show-netlink-error-even-without-extack.patch
  netlink-use-genetlink-ops-information-to-decide-abou.patch
  refactor-interface-between-ioctl-and-netlink-code.patch
* Tue May 12 2020 Michal Kubecek <mkubecek@suse.cz>
- add fixes and improvements originally intended for 5.6:
  netlink-show-netlink-error-even-without-extack.patch
  features-accept-long-legacy-flag-names-when-setting-.patch
  refactor-interface-between-ioctl-and-netlink-code.patch
  netlink-use-genetlink-ops-information-to-decide-abou.patch
* Tue May 12 2020 Michal Kubecek <mkubecek@suse.cz>
- Update to new upstream release 5.6
  * basic infrastructure for netlink kernel interface
  * netlink: support "ethtool <dev>"
  * netlink: support "ethtool -s <dev> ..."
  * netlink: support "ethtool -P <dev>"
  * netlink: monitor support
  * add --debug option
  * netlink: pretty printing of netlink messages
- add libmnl build time dependency
- fix SLE12 build:
  netlink-fix-build-warnings.patch
- minor specfile cleanup
* Mon Jan 13 2020 Michal Kubecek <mkubecek@suse.cz>
- Update to new upstream release 5.4
  * support Energy Detect Power Down
  * Solarflare SFF-8079/8472 eeprom interpretation fixes
  * fix compiler warnings with new gcc
- drop "-Wno-unused-parameter" from CFLAGS, these warnings should
  be gone now
* Sun Nov  3 2019 Michal Kubecek <mkubecek@suse.cz>
- Update to new upstream release 5.3
  * igb: dump RR2DCDELAY register
  * support for dumping nested registers (e.g. CPU port)
* Fri Jul 26 2019 Michal Kubecek <mkubecek@suse.cz>
- Update to new upstream release 5.2
  * support 100BaseT1 and 1000BaseT1 link modes
  * fewer compilation warnings with updated UAPI header copy
* Sat May 18 2019 Michal Kubecek <mkubecek@suse.cz>
- Update to new upstream release 5.1
  * support for 200Gbps (50Gbps per lane) link modes
  * support for new PHY tunable Fast Link Down
  * new 'start N' option when setting Rx flow indirection table
  * add bash completion script
  * support show and set of per queue coalescing
  * fec: add pretty dump
* Thu Mar 14 2019 Michal Kubecek <mkubecek@suse.cz>
- Hide some innocuous build warnings to make relevant ones more
  visible.
* Thu Mar 14 2019 Michal Kubecek <mkubecek@suse.cz>
- Update to new upstream release 5.0
  * Feature: add pretty print for dsa/mv88e6xxx
  * Feature: don't report UFO on kernels >= 4.14
  * Fix (potential): zero initalize coalesce struct
* Fri Nov  2 2018 mkubecek@suse.cz
- Update to new upstream release 4.19
  * Feature: support combinations of FEC modes
  * Fix: unitialized variable in qsfp dump
* Mon Sep 10 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase for summary.
* Fri Aug 24 2018 mkubecek@suse.cz
- Update to new upstream release 4.18
  * Feature: add support WoL using filters
  * Feature: dump strings for ixgbe security registers
* Wed Jun 20 2018 kbabioch@suse.com
- Update to new upstream release 4.17
  * Fix: In ethtool.8, remove superfluous and incorrect \c
  * Fix: fix uninitialized return value
  * Fix: fix RING_VF assignment
  * Fix: remove unused global variable
  * Fix: several fixes in do_gregs()
  * Fix: correctly free hkey when get_stringset() fails
  * Fix: remove unreachable code
  * Fix: fix stack clash in do_get_phy_tunable and do_set_phy_tunable
  * Feature: Add register dump support for MICROCHIP LAN78xx
* Sat Apr 14 2018 mkubecek@suse.cz
- Update to new upstream release 4.16
  * Feature: add support for extra RSS contexts and RSS steering filters
  * Feature: Add SFF 8636 date code parsing support
  * Fix: don't fall back to grxfhindir when context was specified
  * Fix: correct display of VF when showing vf/queue filters
  * Fix: show VF and queue in the help for -N
  * Fix: correct VF index values for the ring_cookie parameter
* Tue Apr 10 2018 mkubecek@suse.cz
- Fix build for targets not (fully) supporting %%license macro
* Tue Apr  3 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Fri Feb  2 2018 mkubecek@suse.cz
- Update to new updstream release 4.15
  * Feature: Support for FEC encoding control
  * Feature: Add extended compliance codes parsing to sfp modules
  * Feature: Add ETHTOOL_RESET support via --reset command
  * Fix: Revert "ethtool: Add DMA Coalescing support"
  * Fix: fix MFLCN register dump for 82599 and newer
* Mon Oct 30 2017 mkubecek@suse.cz
- Update to new upstream release 4.13
  * Feature: add support for HWTSTAMP_FILTER_NTP_ALL
  * Feature: Add DMA Coalescing support
  * Feature: Remove UDP Fragmentation Offload error prints
  * Feature: stmmac: Add DMA HW Feature Register
  * Fix: Do not return error code if no changes were attempted.
  * Fix: Fix formatting of advertise bitmask
  * Fix: fix the rx vs tx mixup in set channel message
* Tue Jun  6 2017 mkubecek@suse.cz
- Update to new upstream release 4.11
  * Feature: Support for configurable RSS hash function
  * Feature: support queue and VF fields for rxclass filters
  * Feature: Add support for 2500baseT/5000baseT link modes
  * Fix: Fix SFF 8079 cable technology bit parsing
  * Fix: sync help output for -x/-X with man page
* Thu Mar 30 2017 mkubecek@suse.cz
- Update to new upstream release 4.10
  * Fix: Fix the "advertise" parameter logic.
  * Feature: Implement ETHTOOL_PHY_GTUNABLE/ETHTOOL_PHY_STUNABLE and PHY downshift
  * Feature: add register dump support for fjes driver (-d option)
- add keyring with John Linville's key for tarball verification
* Tue Oct 11 2016 mkubecek@suse.cz
- Update to new upstream release 4.8
  * Feature: QSFP Plus/QSFP28 Diagnostics Information Support
  * Feature: Enhancing link mode bits to support 25G/50G/100G
  * Feature: add support for 1000BaseX and missing 10G link mode
  * Fixes: address Coverity issues 1363118 - 1363125
* Mon Jul  4 2016 mkubecek@suse.cz
- Update to new upstream release 4.6
  * Feature: Support register dump on Intel X550 NICs (-d option)
  * Fix: Correct some reported register offsets on Intel 10GbE NICs
    (-d option)
  * Feature: Add IPv6 support to NFC (-n, -N, -u and -U options)
  * Feature: Add support for ETHTOOL_xLINKSETTINGS ioctls (no
    option and -s option)
  * Feature: Use netlink socket when AF_INET not available
* Tue Mar 15 2016 mkubecek@suse.cz
- Update to new upstream release 4.5
  * Fix: Heap corruption when dumping registers from a file
    (-d option)
  * Fix: Stricter input validation for EEPROM setting (-E option)
  * Feature: Add PHY statistics support (--phy-statistics option)
  * Feature: Support setting default Rx flow indirection table
    (-X option)
  * Doc: Properly indent sub-options in man page
  * address build issues (mostly compiler warnings)
* Fri Oct  9 2015 mkubecek@suse.cz
- Update to new upstream release 4.2
  * Feature: Support soldered-on modules in module EEPROM dump
    (-m option)
  * Feature: Add register dump support for VMware vmxnet3
    (-d option)
  * Feature: Update register dump support for IBM EMAC (-d option)
    (requires Linux 4.3 or a future stable update to 4.1 or 4.2)
  * Doc: Fix typo in man page
* Mon Jun  1 2015 mkubecek@suse.cz
- Update to new upstream release 4.0
  * Fix: Formatting of RX flow hash indirection table when size not
    divisible by 8 (-x option)
  * Fix: Add missing Advertised speeds (no option and -s option)
  * Feature: Add support to get expansion ROM version (-i option)
  * Feature: Include SFP serial number and date in EEPROM dump
    (-m option)
* Sun Jan 11 2015 jengelh@inai.de
- Update to new upstream release 3.18
  * Fix: Lookup of SFP Tx bias in SFF-8472 module diagnostics
  (-m option)
- Drop usrmerge compat symlinks
* Tue Nov 18 2014 jengelh@inai.de
- Update to new upstream release 3.16
  * Support for configurable RSS hash key (-x/-X options)
  * Add register dump support for Altera Triple Speed Ethernet
  (-d option)
  * Report Backplane as a supported port
- Remove unused call to %%gpg_verify (the macro expands to nothing);
  source validation handled by osc.
* Thu Feb  6 2014 puzel@suse.com
- Drop ethtool-display-switch-port-attributes.patch (failed
  upstream acceptance and has to be reworked)
* Thu Dec  5 2013 puzel@suse.com
- Add '-q' command line option to display switch port attributes
  (bnc#853637, fate#315293)
- added patches:
  * ethtool-display-switch-port-attributes.patch
* Sun Nov 24 2013 p.drouand@gmail.com
- Update to version 3.12.1
  * Fix: Memory corruption when applying external calibration to
  SFF-8472 module diagnostics (-m option)
  * Feature: Add Intel 82599 and x540 DCB registers to dump
  (-d option)
- Changes from 3.12
  * Fix: Remove alternate method to check for VLAN tag offload on Linux
  < 2.6.37 (-k/-K options)
  * Fix: Hide state of VLAN tag offload and LRO if the kernel is too old
  for us to reliably detect them (-k option)
  * Feature: Add register dump support for Solarflare SFC9100 family
  (-d option)
- Changes from 3.11
  * Feature: Update Realtek chip list for register dump to match
  r8169 driver in Linux 3.11 (-d option)
  * Feature: Add ixgbevf support for register dump (-d option)
  * Feature: Filter ixgbe register dump according to the specific chip
  (-d option)
* Thu Jul  4 2013 jengelh@inai.de
- Update to new upstream release 3.10
  * Displaying of support for 10000BASE-KR link mode was implemented.
  * Support for new versions of ixgbe register dump was added.
  * The private flags print output was beautified.
- More robust make install call
- Optional signature verification
* Mon Apr 22 2013 puzel@suse.com
- Update to new upstream release 3.8
  * Feature: Allow setting destination MAC address in L3/L4 flow
    spec rules (-N/-U option)
  * Fix: Show full 64 bits of user-data (-n/-u option)
  * Fix: Add version check for et131x regs (-d option)
  * Doc: Improve description of -f, -t, -s, -N/-U, -W options in
    man page
  * Fix: Restore 20000baseKR2 cap display (no options)
* Mon Dec 17 2012 puzel@suse.com
- Update to new upstream release 3.7
  * Fix: Gracefully handle failure of register pretty-printer (-d
    option)
  * Feature: Add support for et131x registers (-d option)
  * Feature: Basic optical diagnostics for SFF-8472 modules (-m
    option)
* Mon Oct  8 2012 puzel@suse.com
- Update to new upstream release 3.6
  * Feature: Allow setting MDI-X state (-s option)
  * Fix: Preserve pause advertising bits when setting speed and
    duplex with autoneg on (-s option)
  * Fix: Don't call ioctl to set EEE parameters if they are the
    same as the current parameters (--set-eee option)
* Mon Aug  6 2012 puzel@suse.com
- Update to new upstream release 3.5
  * Display support for 1000BASE-KX and 10GBASE-KX4 link modes
  * Energy-Efficient Ethernet (EEE) configuration
    (--show-eee and --set-eee options)
  * Display support for 40G link modes
  * Fix: Don't trust drivers to null-terminate strings
* Sat Jun 16 2012 jengelh@inai.de
- Update to new upstream release 3.4.1
  * This release adds reporting of driver features ("-i")
  * reporting of supported pause frame modes and of 20G link modes
  * firmware dumps ("-w" and "-W")
  * external loopback tests ("-t")
  * reporting and configuring the number of channels/queues
  ("-l" and "-L") and time stamping capabilities ("-T")
  * reporting of pause frame autonegotiation results ("-a")
  * support for querying and setting all generic net device features
  ("-k" and "-K") and private flags
  * dumping of plugin module EEPROM ("-m")
* Wed May 16 2012 andreas.stieger@gmx.de
- Add xz build requirement to fix build for openSUSE 11.4
* Mon Feb 27 2012 puzel@suse.com
- update to ethtool-3.2
  * Feature: Add support for querying and setting private flags
    (--show-priv-flags, --set-priv-flags options)
  * Feature: Omit zero values in Solarflare register tables (-d
    option)
  * Feature: Allow driver to select RX NFC rule location (-U
    option)
  * Fix: Correct register dump offsets for Intel 82575 chipsets
    (-d option)
* Wed Feb  8 2012 rschweikert@suse.com
- keep binary in /usr tree (UsrMerge project)
* Tue Dec 13 2011 puzel@suse.com
- update to ethtool-3.1
  * Fix: Show all non-zero registers for tg3 (-d option)
  * Feature: Add support for external loopback test (-t option)
  * Fix: Show correct flow control registers for Intel 82599 (-d option)
  * Feature: Add support for reporting and configuring numbers of
    channels/queues (-l and -L options)
  * Feature: Report pause frame autonegotiation result (-a option)
  * Doc: Change device name metavariable from 'ethX' to 'devname'
  * Doc: Fix various layout problems
  * Cleanup: Reorganise and add test cases for argument parsing
  * Fix: Strictly check for extraneous or missing arguments; in
    particular, fail if the device name is missing
* Wed Dec  7 2011 cfarrell@suse.com
- license update: GPL-2.0
  sfc.c and stmmac.c have GPL-2.0 licenses
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Mon Aug  8 2011 puzel@novell.com
- update to ethtool-3.0
  * Feature: Report supported pause frame modes
  * Feature: Support firmware dump (-w and -W options)
  * Feature: Report advertised and supported 20G link modes
  * Feature: Add an 'l4data' option for ip4 filters (-U option)
  * Fix: Correct swapped h_source and h_dest fields for ether
    filters (-U option)
  * Fix: Set ip_ver field correctly for ip4 filters (-U option)
  * Fix: Correct parameter validation for -e and -E options; in
    particular, treat the 'magic' value as unsigned
  * Feature: Report some driver features (-i option)
  * Doc: Remove misleading 'Auto' advertising mask from manual page
  * Doc: Improve table formatting on manual page, using tbl
  * Doc: Remove initial blank page in printed manual page
  * Doc: Fix line-wrapping of options
  * Feature: Add support for ESP as a separate protocol from AH
    (-n, -N, -u and -U options)
  * Cleanup: Remove support for showing RX n-tuple settings
    (-u option), which was never implemented correctly in the kernel
  * Feature: Add support for RX network flow classifier (NFC)
    (-u and -U options)
  * Feature: Add support for e1000 M88 PHY registers (-d option)
  * Cleanup: Change bug-address to netdev
- use spec-cleaner
* Tue Mar 15 2011 bphilips@novell.com
- Update to ethtool-2.6.38
  * Doc: Fix spelling and spacing in online help
  * Doc: Update date, version and web site reference in manual page
  * Doc: Fix spelling, capitalisation, consistency and style in
    manual page
  * Doc: Generalise some references to network devices rather than
    Ethernet devices
  * Fix: Don't silently ignore speed/duplex when autoneg is on
  * Fix: Report an error (rather than full usage information) if
    given an unrecognised option
  * Feature: Add --version option
* Thu Nov 18 2010 puzel@novell.com
- update to ethtool-2.6.36
  * Fix: RX n-tuple masks and documentation
  * Feature: Ethernet-level RX n-tuple filtering and 'clear' action
  * Feature: stmmac register dump support
  * Feature: get permanent address (-P) option
  * Feature: VLAN acceleration control
  * Feature: sfc register dump support
  * Feature: improve cmd line parsing of ints, IPv4 addresses
  * Feature: support ethtool named flags, messaging types
  * Feature: minor man page fixes
  * Feature: control RX flow hash indirection
* Tue Jul 27 2010 puzel@novell.com
- update to ethtool-2.6.34
  * Feature: Support n-tuple filter programming
  * Feature: Support rx hashing, v2 (targetted for 2.6.35)
  * Feature: Add names of newer Marvell chips
  * new release numbering scheme, based
    on the latest upstream kernel interface supported.
  * Fix: several man page corrections
  * Feature: rx flow hash configuration
  * Feature: report 10000baseT support, where available
  * Feature: report MDI-X status, pause auto-neg, link partner
    adverts
  * Feature: support additional port types
  * Feature: support arbitrary speeds, faster than 65535 Mb
  * Feature: large and generic receive offload (LRO, GRO) support
  * Feature: option to flash firmware image from specified file
  * Feature: support for block writing of EEPROMs
  * Feature: marvell register dump update
  * Feature: at76c50x-usb, e1000e, igb, ixgbe, r8169 register
    dump support
  * Cleanup: remove support for RX hashing by port
  * Doc: Explicitly ship GPLv2 license
- drop all patches (fixed upstream)
* Mon Jul 12 2010 puzel@novell.com
- add get-set-gro-settings.patch (bnc#616263)
* Fri Jan  8 2010 jengelh@medozas.de
- enable parallel build
* Tue Dec  1 2009 mseben@novell.com
- add speed-parse.patch : fix parse of 10Gbe option (bnc#557016)
- add cmd-speed-display-all.patch Display all NIC speeds [FATE#305494]
* Tue Nov  4 2008 hvogel@suse.de
- Add support for LRO (Large Receive Offload) [bnc#440003]
* Fri Sep 12 2008 bphilips@suse.de
- Add support for larger speed field to do greater than 65535Mb/s devices
* Wed Dec 19 2007 mskibbe@suse.de
- Bug 285472 - network script does not work for /usr over NFS
* Fri Jul 27 2007 mskibbe@suse.de
- update to version 6 which includes:
  o updates for a lot of NICs
  o preparing for 10G NICs
  o a log Bugfixes
* Thu Apr 12 2007 lnussel@suse.de
- remove superfluous buffer overflow check patch
* Wed Sep  6 2006 mskibbe@suse.de
- fix bug #202756 - No Buffer Overflow check in Ethtool
* Mon Sep  4 2006 mskibbe@suse.de
- update to version 5 which includes:
  o Security: Avoid potential buffer overflow
  o Feature: GSO support
  o Feature: skge register dump
* Thu Aug 31 2006 mskibbe@suse.de
- update to version 4 which
  o includes UFO support
  o support long options
  o includes e1000, pcnet32, tg3 updates
  o added PPC4xx EMAC support
  o Use hexdump instead of single values for register dump
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 29 2005 hvogel@suse.de
- update to version 3
* Mon Aug 23 2004 mmj@suse.de
- Update to ethtool-2 which includes all our patches
* Thu Jun 24 2004 meissner@suse.de
- Added pcnet32 register dumping LTC#9592/SUSE#42408.
* Mon May 24 2004 meissner@suse.de
- return error value from test option LTC#7166/SUSE#40960.
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Tue Aug 26 2003 pthomas@suse.de
- Upgraded to 1.8
* Tue Aug 26 2003 pthomas@suse.de
- Remove the bogus rejection of devices whose names that do not begin
  with either 'eth' or 'usb'.
* Mon Jun  2 2003 pthomas@suse.de
- Add support for AMD-8111.
* Fri Feb  7 2003 meissner@suse.de
- Upgraded to current CVS, which has some e1000 fixes needed by IBM.
* Thu Feb  6 2003 meissner@suse.de
- Upgraded to 1.7:
* Mon Jun 24 2002 pthomas@suse.de
- Initial package creation.
- Fix most gcc warnings.
